Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3201)

Unified Diff: chrome/browser/ui/sync/sync_promo_ui.cc

Issue 2494873003: [Sync] Allow sync start without sign-in if the local sync backend is on. (Closed)
Patch Set: Merge pref changes from https://codereview.chromium.org/2528163002/. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/sync/sync_promo_ui.cc
diff --git a/chrome/browser/ui/sync/sync_promo_ui.cc b/chrome/browser/ui/sync/sync_promo_ui.cc
index 3fa574b6483f4358dad9aa04427e099145d549d1..bf9fde37de83e3f71a17874dec4cecfb894c8ffe 100644
--- a/chrome/browser/ui/sync/sync_promo_ui.cc
+++ b/chrome/browser/ui/sync/sync_promo_ui.cc
@@ -13,8 +13,8 @@ bool SyncPromoUI::ShouldShowSyncPromo(Profile* profile) {
return false;
}
- // Don't show if sync is not allowed to start.
- if (!profile->IsSyncAllowed())
+ // Don't show if sync is not allowed to start or is running in local mode.
+ if (!profile->IsSyncAllowed() || profile->IsLocalSyncEnabled())
Nicolas Zea 2016/12/15 00:37:28 See other comment. Is this the only callsite that
pastarmovj 2016/12/16 17:04:48 Yes this is the only site that needs IsLocalSyncEn
return false;
return true;

Powered by Google App Engine
This is Rietveld 408576698